==> univention-portal_4.0.16-1.tar.gz: univention-portal-4.0.16/frontend/src/jsHelper/login.ts <==
/*
 * Like what you see? Join us!
 * https://www.univention.com/about-us/careers/vacancies/
 *
 * Copyright 2021-2024 Univention GmbH
 *
 * https://www.univention.de/
 *
 * All rights reserved.
 *
 * The source code of this program is made available
 * under the terms of the GNU Affero General Public License version 3
 * (GNU AGPL V3) as published by the Free Software Foundation.
 *
 * Binary versions of this program provided by Univention to you as
 * well as other copyrighted, protected or trademarked materials like
 * Logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and Univention and not subject to the GNU AGPL V3.
 *
 * In the case you use this program under the terms of the GNU AGPL V3,
 * the program is provided in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License with the Debian GNU/Linux or Univention distribution in file
 * /usr/share/common-licenses/AGPL-3; if not, see
 * <https://www.gnu.org/licenses/>.
 */
import { User } from '@/store/modules/user/user.models';

function login(user: User): void {
  if (user.authMode === 'saml') {
    window.location.href = `/univention/saml/?location=${window.location.pathname}`;
  } else {
    window.location.href = `/univention/login/?location=${window.location.pathname}`;
  }
}

function logout(): void {
  window.location.href = `/univention/logout/?location=${window.location.pathname}`;
}

export { login, logout };

==> univention-portal_4.0.18-2.tar.gz: univention-portal-4.0.18/frontend/src/jsHelper/login.ts <==
/*
 * Like what you see? Join us!
 * https://www.univention.com/about-us/careers/vacancies/
 *
 * Copyright 2021-2024 Univention GmbH
 *
 * https://www.univention.de/
 *
 * All rights reserved.
 *
 * The source code of this program is made available
 * under the terms of the GNU Affero General Public License version 3
 * (GNU AGPL V3) as published by the Free Software Foundation.
 *
 * Binary versions of this program provided by Univention to you as
 * well as other copyrighted, protected or trademarked materials like
 * Logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and Univention and not subject to the GNU AGPL V3.
 *
 * In the case you use this program under the terms of the GNU AGPL V3,
 * the program is provided in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License with the Debian GNU/Linux or Univention distribution in file
 * /usr/share/common-licenses/AGPL-3; if not, see
 * <https://www.gnu.org/licenses/>.
 */
import { User } from '@/store/modules/user/user.models';

function login(user: User): void {
  if (user.authMode === 'saml') {
    window.location.href = `/univention/saml/?location=${window.location.pathname}`;
  } else if (user.authMode === 'oidc') {
    window.location.href = `/univention/oidc/?location=${window.location.pathname}`;
  } else {
    window.location.href = `/univention/login/?location=${window.location.pathname}`;
  }
}

function logout(): void {
  window.location.href = `/univention/logout/?location=${window.location.pathname}`;
}

export { login, logout };
